@@ -494,6 +494,9 @@ class Project:
             except Exception as e:
                 log_error('Failed to generate code for component "%s". Reason: %s' \
                           % (component.name, e) )
+        
+        # Delete pickle file
+        cg.delete_file(pickle_full_file_name)
     
     #===============================================================================================
     def validate_given_simple_params(self, component, simple_params_list):
@@ -1121,13 +1124,12 @@ class Project:
                         dest_file = out_path / "usr_in" / str(input_file)
                         shutil.copy(in_file, dest_file)
                         
-                        # Export any found markdown document
+                        # Export any found pdf document
                         if cg.folder_exists(out_path / "doc") is False:
                             cg.create_folder(out_path / "doc")
                         doc_path = root_path / "doc"
-                        for doc_file in doc_path.glob('*.md'):
+                        for doc_file in doc_path.glob('*.pdf'):
                             if doc_file.is_file() is True:
-                                print("File: ", doc_file)
                                 dest_file = out_path / "doc" / doc_file.name
                                 # copy to demo project doc folder
                                 shutil.copy(doc_file, dest_file)
